==> haskell-html-conduit-1.3.2.2-217-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-6VKmfRDRxnvQvsgZw2yzj
key:                  html-conduit-1.3.2.2-6VKmfRDRxnvQvsgZw2yzj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  5357104b0ba6c685b3ffa730aefc3881
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-6VKmfRDRxnvQvsgZw2yzj
depends:
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb containers-0.6.5.1
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM text-1.2.5.0
    transformers-0.5.6.2 xml-conduit-1.9.1.3-78hprMCLgMFFWPQU2FN158
    xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.2.2-232-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-3IUsEAE0avc6ithdSPc59g
key:                  html-conduit-1.3.2.2-3IUsEAE0avc6ithdSPc59g
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  355cd6820692f5fc01eb18910c85cf6b
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-3IUsEAE0avc6ithdSPc59g
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD containers-0.6.5.1
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD text-1.2.5.0
    transformers-0.5.6.2 xml-conduit-1.9.1.3-AwLhlaz27ql1567v7tH4L6
    xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
